/**
 * Collects callback functions to be invoked.
 */
export class CustomEventHandler {
    private _listeners: (() => void)[] = [];


    /**
     * Adds a listener to be invoked when `invokeListeners` is called.
     *
     * @param listener a listener to invoke when `invokeListeners` is called
     */
    addListener(listener: () => void) {
        this._listeners.push(listener);
    }

    /**
     * Invokes all listeners that were added using `addListener`.
     */
    invokeListeners() {
        this._listeners.forEach(it => it());
    }
}
