<?php

namespace com\fwdekker\deathnotifier;

use com\fwdekker\deathnotifier\validation\InvalidValueException;


/**
 * Periodically executes several other actions, as if cron jobs have been set up to do so.
 *
 * Intended for local development only.
 */
class EmulateCronAction extends Action
{
    /**
     * The number of seconds between executing tasks.
     */
    private const INTERVAL = 15;

    /**
     * @var Action[] the actions to execute at an interval
     */
    private readonly array $actions;


    /**
     * Constructs a new `EmulateCronAction`.
     *
     * @param Action[] $actions the `Action`s to execute at an interval
     */
    public function __construct(array $actions)
    {
        $this->actions = $actions;
    }


    /**
     * Updates all trackings and processes the mail queue at a regular interval.
     *
     * @param array<int|string, mixed> $inputs the inputs to perform the action with
     * @return never
     * @throws InvalidValueException if any of the inputs is invalid
     * @throws UnexpectedException if the action could not be performed even though the inputs are valid
     * @noinspection PhpDocRedundantThrowsInspection may be thrown by {@see $actions}
     */
    public function handle(array $inputs): never
    {
        $logger = LoggerUtil::with_name($this::class);
        // @phpstan-ignore-next-line
        while (true) {
            $logger->notice("Emulating cron job.");
            foreach ($this->actions as $action)
                $action->handle($inputs);
            print("Done.\n");

            sleep(self::INTERVAL);
        }
    }
}
