<?php

namespace com\fwdekker\deathnotifier\mailer;


/**
 * An email is a succinct way of passing around an email based on just a few parameters.
 *
 * Two emails may be considered the same even if some parameters are different. Because equality testing is performed
 * inside a database, it is not possible to, say, require each class to specify its own `equals` method. Instead, two
 * `Email` instances are equivalent if and only if their {@see Email::$recipient} are the same and their
 * {@see Email::$type_key} are the same.
 */
abstract class Email
{
    /**
     * @var string the identifier of this email
     */
    public readonly string $type_key;
    /**
     * @var string the intended recipient of this email
     */
    public readonly string $recipient;


    /**
     * Constructs a new `Email`.
     *
     * @param string $type_key the identifier of this email
     * @param string $recipient the intended recipient of this email
     */
    public function __construct(string $type_key, string $recipient)
    {
        $this->type_key = $type_key;
        $this->recipient = $recipient;
    }


    /**
     * Returns the subject header of this email.
     *
     * @return string the subject header of this email
     */
    public abstract function get_subject(): string;

    /**
     * Returns the body of this email.
     *
     * @return string the body of this email
     */
    public abstract function get_body(): string;
}
