<?php

namespace com\fwdekker\deathnotifier\validation;


/**
 * Validates that the input is a boolean.
 */
class IsBooleanRule extends Rule
{
    /**
     * Validates that the input is a boolean.
     *
     * @param array<int|string, mixed> $inputs the list of inputs in which the value at {@see $key} should be checked
     * @param string $key the key in {@see $inputs} of the input to check
     * @return void if the checked input is a boolean
     * @throws InvalidTypeException if the checked input is not set or if the checked input is not a boolean
     */
    public function check(array $inputs, string $key): void
    {
        if (!isset($inputs[$key]))
            throw new InvalidTypeException("Required input '$key' not set.");
        if (!is_bool($inputs[$key]))
            throw new InvalidTypeException("Input '$key' should be boolean, but is " . gettype($inputs[$key]) . ".");
    }
}
