<?php

namespace com\fwdekker\deathnotifier\validation;


/**
 * Validates that the input is an email address.
 */
class IsEmailRule extends Rule
{
    /**
     * Validates that the input is an email address.
     *
     * @param array<int|string, mixed> $inputs the list of inputs in which the value at {@see $key} should be checked
     * @param string $key the key in {@see $inputs} of the input to check
     * @return void if the checked input is an email address
     * @throws InvalidTypeException if the checked input is not set or is not a string
     * @throws InvalidValueException if the checked input is not an email address
     */
    public function check(array $inputs, string $key): void
    {
        if (!isset($inputs[$key]))
            throw new InvalidTypeException("Required input '$key' not set.");
        if (!is_string($inputs[$key]))
            throw new InvalidTypeException("Input '$key' should be string, but is " . gettype($inputs[$key]) . ".");

        $input = $inputs[$key];
        if (str_starts_with($input, " "))
            throw new InvalidValueException("Remove the spaces at the start.", $key);
        if (str_ends_with($input, " "))
            throw new InvalidValueException("Remove the spaces at the end.", $key);
        if ($input === "")
            throw new InvalidValueException("Enter an email address.", $key);
        if (!str_contains($input, "@"))
            throw new InvalidValueException("Don't forget to add an '@' symbol.", $key);
        if (str_ends_with($input, "@"))
            throw new InvalidValueException("Add a domain name after the '@'.", $key);
        if (!filter_var($input, FILTER_VALIDATE_EMAIL))
            throw new InvalidValueException("Enter a valid email address.", $key);
    }
}
