<?php

namespace com\fwdekker\deathnotifier\validation;


/**
 * Validates that the input is a valid CSRF token.
 */
class IsValidCsrfTokenRule extends Rule
{
    /**
     * Validates that the input is a valid CSRF token.
     *
     * @param array<int|string, mixed> $inputs the list of inputs in which the value at {@see $key} should be checked
     * @param string $key the key in {@see $inputs} of the input to check
     * @return void if the checked input is a valid CSRF token
     * @throws InvalidTypeException if the checked input is not set or if the checked input is not a string
     * @throws InvalidValueException if the checked input is not a valid CSRF token
     */
    public function check(array $inputs, string $key): void
    {
        if (!isset($inputs[$key]))
            throw new InvalidTypeException("Missing CSRF token.");
        if (!is_string($inputs[$key]))
            throw new InvalidTypeException("CSRF token should be string, but is " . gettype($inputs[$key]) . ".");

        if ($inputs[$key] !== $_SESSION["token"])
            throw new InvalidValueException("Invalid CSRF token. Please refresh the page and try again.", $key);
    }
}
