<?php

namespace com\fwdekker\deathnotifier\validation;

use com\fwdekker\deathnotifier\IllegalArgumentError;


/**
 * Like a {@see RuleSet}, but specifically to validate whether the user is logged in.
 */
class LoginValidator
{
    /**
     * @var bool `true` if and only if this validator should check if the user is logged in
     */
    private readonly bool $validate_logged_in;
    /**
     * @var bool `true` if and only if this validator should check if the user is logged out
     */
    private readonly bool $validate_logged_out;


    /**
     * Constructs a new `LoginValidator`.
     *
     * @param bool $validate_logged_in `true` if and only if this validator should check if the user is logged in
     * @param bool $validate_logged_out `true` if and only if this validator should check if the user is logged out
     */
    public function __construct(bool $validate_logged_in = false, bool $validate_logged_out = false)
    {
        if ($validate_logged_in && $validate_logged_out)
            throw new IllegalArgumentError("Cannot require that user is both logged in and logged out.");
        if (!$validate_logged_in && !$validate_logged_out)
            throw new IllegalArgumentError("Must require that user is either logged in or logged out.");

        $this->validate_logged_in = $validate_logged_in;
        $this->validate_logged_out = $validate_logged_out;
    }


    /**
     * Checks whether the user's login status is as desired.
     *
     * @param array<int|string, mixed> $inputs the list of inputs to validate
     * @return void if the user's login status is as desired
     * @throws InvalidValueException if the user's login status is not as desired
     */
    public function check(array $inputs): void
    {
        if ($this->validate_logged_in && !isset($inputs["uuid"]))
            throw new InvalidValueException(
                "You must be logged in to perform this action. Please refresh the page and try again."
            );

        if ($this->validate_logged_out && isset($inputs["uuid"]))
            throw new InvalidValueException(
                "You must be logged out to perform this action. Please refresh the page and try again."
            );
    }
}
