<?php

namespace com\fwdekker\deathnotifier\validation;


/**
 * A rule/constraint/assertion that should hold over an input.
 */
abstract class Rule
{
    /**
     * Checks whether the rule holds for `$inputs[$key]`.
     *
     * @param array<int|string, mixed> $inputs the list of inputs in which the value at {@see $key} should be checked
     * @param string $key the key in {@see $inputs} of the input to check
     * @return void if the rule holds for the checked input
     * @throws InvalidTypeException if the checked input is not set or of the wrong type
     * @throws InvalidValueException if the rule does not hold for the checked input
     */
    public abstract function check(array $inputs, string $key): void;
}
