<?php

namespace com\fwdekker\deathnotifier\validation;


/**
 * A set of {@see Rule Rules} to apply to an array of inputs.
 */
class RuleSet
{
    /**
     * @var array<string, array<Rule>> a mapping from input keys to the array of rules to apply to that input
     */
    private readonly array $rule_lists;


    /**
     * Constructs a new `RuleSet`.
     *
     * @param array<string, array<Rule>> $rule_lists a mapping from input keys to the array of rules to apply to that
     * input
     */
    public function __construct(array $rule_lists)
    {
        $this->rule_lists = $rule_lists;
    }


    /**
     * Verifies that the input is of the specific length.
     *
     * @param array<int|string, mixed> $inputs the list of inputs to validate
     * @return void if the inputs satisfy the rules of this rule set
     * @throws InvalidTypeException if any rule throws this exception for any input
     * @throws InvalidValueException if any rule throws this exception for any input
     */
    public function check(array $inputs): void
    {
        foreach ($this->rule_lists as $key => $rule_list)
            foreach ($rule_list as $rule)
                $rule->check($inputs, $key);
    }
}
