<?php

namespace com\fwdekker\deathnotifier\wikipedia;


/**
 * Output of a {@see Wikipedia} query.
 *
 * @template T the type of result that is returned
 */
class QueryOutput
{
    /**
     * @var array<string, T> the results of the query, either raw from the API or processed in some way
     */
    public readonly array $results;
    /**
     * @var Redirects mapping of queried names to normalized/redirected names
     */
    public readonly Redirects $redirects;
    /**
     * @var string[] list of missing articles
     */
    public readonly array $missing;


    /**
     * Constructs a new `QueryOutput`, storing both the result returned by the API, and information on which requested
     * pages are redirected or missing.
     *
     * @param array<string, T> $results the results of the query, either raw from {@see Wikipedia} or processed in some
     * way
     * @param Redirects $redirects mapping of queried names to normalized/redirected names
     * @param string[] $missing list of missing articles
     */
    public function __construct(array $results, Redirects $redirects, array $missing)
    {
        $this->results = $results;
        $this->redirects = $redirects;
        $this->missing = $missing;
    }
}
