<?php /** @noinspection PhpUnhandledExceptionInspection */

namespace com\fwdekker\deathnotifier\validation;

use com\fwdekker\deathnotifier\IllegalArgumentError;
use PHPUnit\Framework\TestCase;


/**
 * Unit tests for {@see LoginValidator}.
 */
class LoginValidatorTest extends TestCase
{
    public function test_constructor_throws_exception_if_user_should_be_both_logged_in_and_logged_out(): void
    {
        self::expectException(IllegalArgumentError::class);

        new LoginValidator(validate_logged_in: true, validate_logged_out: true);
    }

    public function test_constructor_throws_exception_if_user_should_be_neither_logged_in_nor_logged_out(): void
    {
        self::expectException(IllegalArgumentError::class);

        new LoginValidator(validate_logged_in: false, validate_logged_out: false);
    }


    public function test_check_throws_exception_if_log_in_required_but_not_logged_in(): void
    {
        self::expectException(InvalidValueException::class);

        (new LoginValidator(validate_logged_in: true))->check([]);
    }

    public function test_check_no_exception_if_log_in_required_and_logged_in(): void
    {
        (new LoginValidator(validate_logged_in: true))->check(["uuid" => "my-uuid"]);

        self::assertTrue(true);
    }

    public function test_check_throws_exception_if_log_out_required_but_not_logged_out(): void
    {
        self::expectException(InvalidValueException::class);

        (new LoginValidator(validate_logged_out: true))->check(["uuid" => "my-uuid"]);
    }

    public function test_check_no_exception_if_log_out_required_and_logged_out(): void
    {
        (new LoginValidator(validate_logged_out: true))->check([]);

        self::assertTrue(true);
    }
}
