<?php /** @noinspection PhpUnhandledExceptionInspection */

namespace com\fwdekker\deathnotifier\validation;

use PHPUnit\Framework\TestCase;


/**
 * Unit tests for {@see RuleSet}.
 */
class RuleSetTest extends TestCase
{
    public function test_no_exception_if_no_rule_lists(): void
    {
        $rules = [];
        $inputs = ["key1" => "value1", "key2" => "value2"];

        (new RuleSet($rules))->check($inputs);

        self::assertTrue(true);
    }

    public function test_no_exception_if_empty_rule_lists(): void
    {
        $rules = ["key1" => [], "key3" => []];
        $inputs = ["key1" => "value1", "key2" => "value2"];

        (new RuleSet($rules))->check($inputs);

        self::assertTrue(true);
    }

    public function test_exception_if_single_invalid_rule(): void
    {
        $rules = ["key1" => [new IsStringRule()]];
        $inputs = ["key2" => "value2"];

        self::expectException(InvalidTypeException::class);
        (new RuleSet($rules))->check($inputs);
    }

    public function test_exception_for_first_invalid_rule_in_first_rule_list(): void
    {
        $rules = ["key1" => [new IsStringRule(), new IsEmailRule()], "key2" => [new IsStringRule()]];
        $inputs = ["key3" => "value3"];

        self::expectException(InvalidTypeException::class);
        self::expectExceptionMessage("Required input 'key1' not set.");
        (new RuleSet($rules))->check($inputs);
    }
}
