<?php

namespace com\fwdekker\deathnotifier\validation;

use PHPUnit\Framework\TestCase;
use Throwable;


/**
 * Unit tests for {@see Rule} implementations.
 */
abstract class RuleTestTemplate extends TestCase
{
    /**
     * Tests the output of {@see Rule::check()}.
     *
     * @param Rule $rule the rule to check
     * @param mixed|null $input the user's input
     * @param class-string<Throwable>|null $exception the exception that is asserted to be thrown
     * @param string|null $exception_message the exception message that is asserted to be thrown
     * @return void
     * @throws InvalidTypeException never
     * @throws InvalidValueException never
     * @dataProvider check_provider
     */
    public function test_check(Rule $rule, mixed $input, ?string $exception, ?string $exception_message): void
    {
        if ($exception !== null)
            self::expectException($exception);
        if ($exception_message !== null)
            self::expectExceptionMessage($exception_message);

        $rule->check(["key" => $input], "key");

        if ($exception === null && $exception_message === null)
            self::assertTrue(true);
    }

    /**
     * Returns the test cases.
     *
     * @return array<string, array{Rule, mixed|null, class-string<Throwable>|null, string|null}> the test cases
     * @see RuleTestTemplate::test_check()
     */
    abstract public static function check_provider(): array;
}
